Config

Struct Config 

pub struct Config {
    pub database_url: Option<String>,
    pub default_queue: Option<String>,
    pub default_limit: Option<u32>,
    pub log_level: Option<String>,
    pub connection_pool_size: Option<u32>,
}
CLI configuration structure.

This struct holds all configuration options for the Hammerwork CLI. Fields are optional to allow partial configuration and merging from multiple sources.

Examples

use cargo_hammerwork::config::Config;

// Create configuration with defaults
let config = Config::default();
assert_eq!(config.get_default_limit(), 50);
assert_eq!(config.get_log_level(), "info");
assert_eq!(config.get_connection_pool_size(), 5);

Fields

database_url: Option<String>

Database connection URL (e.g., “postgresql://localhost/hammerwork”)

default_queue: Option<String>

Default queue name for operations

default_limit: Option<u32>

Default limit for list operations

log_level: Option<String>

Log level (error, warn, info, debug, trace)

connection_pool_size: Option<u32>

Database connection pool size

Implementations

Source

impl Config

pub fn load() -> Result<Self>

Load configuration from file and environment variables.

Configuration is loaded with the following precedence:

  1. Environment variables (highest priority)
  2. Configuration file at ~/.config/hammerwork/config.toml
  3. Default values (lowest priority)
Examples
use cargo_hammerwork::config::Config;

let config = Config::load().expect("Failed to load configuration");
println!("Database URL: {:?}", config.database_url);
pub fn save(&self) -> Result<()>

Save configuration to file.

The configuration is saved to the platform-specific location:

  • Linux/Mac: ~/.config/hammerwork/config.toml
  • Windows: %APPDATA%\hammerwork\config.toml
Examples
use cargo_hammerwork::config::Config;

let mut config = Config::default();
config.database_url = Some("postgresql://localhost/hammerwork".to_string());
config.save().expect("Failed to save configuration");
pub fn get_database_url(&self) -> Option<&str>

pub fn get_default_queue(&self) -> Option<&str>

pub fn get_default_limit(&self) -> u32

pub fn get_log_level(&self) -> &str

pub fn get_connection_pool_size(&self) -> u32